==> apache-camel-quarkus-3.4.0-src.zip: camel-quarkus-3.4.0/integration-tests/messaging/jms/src/main/java/org/apache/camel/quarkus/messaging/jms/JmsRoutes.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.messaging.jms;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;
import jakarta.transaction.TransactionManager;
import org.apache.camel.BindToRegistry;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.quarkus.component.messaging.it.util.scheme.ComponentScheme;
import org.springframework.transaction.PlatformTransactionManager;
import org.springframework.transaction.jta.JtaTransactionManager;

@ApplicationScoped
public class JmsRoutes extends RouteBuilder {

    @Inject
    ComponentScheme componentScheme;

    @Inject
    TransactionManager transactionManager;

    @Override
    public void configure() throws Exception {

        fromF("%s:queue:testJmsTransferExchange?transferExchange=true", componentScheme)
                .to("mock:transferExchangeResult");

        fromF("%s:queue:testJmsTransferException?transferException=true", componentScheme)
                .throwException(new IllegalStateException("Forced exception"));

        from("direct:computedDestination")
                .bean("destinationHeaderSetter")
                .toF("%s:queue:override", componentScheme);

        fromF("%s:queue:xa?transactionManager=#jtaTransactionManager", componentScheme)
                .routeId("xaConsumer")
                .log("Received message ${body}")
                .to("mock:xaResult");

        from("direct:xa")
                .routeId("xa")
                .transacted()
                .process(x -> {
                    transactionManager.getTransaction().enlistResource(new DummyXAResource());
                })
                .toF("%s:queue:xa?disableReplyTo=true", componentScheme)
                .choice()
                .when(body().startsWith("fail"))
                .log("Forced to rollback")
                .process(x -> {
                    transactionManager.setRollbackOnly();
                })
                .otherwise()
                .log("Message added: ${body}")
                .endChoice();
    }

    @BindToRegistry("jtaTransactionManager")
    public PlatformTransactionManager getTransactionManager() {
        return new JtaTransactionManager(transactionManager);
    }
}

==> apache-camel-quarkus-3.15.4-src.zip: camel-quarkus-3.15.4/integration-tests/messaging/jms/src/main/java/org/apache/camel/quarkus/messaging/jms/JmsRoutes.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.messaging.jms;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;
import jakarta.inject.Named;
import jakarta.transaction.TransactionManager;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.quarkus.component.messaging.it.util.scheme.ComponentScheme;
import org.springframework.transaction.PlatformTransactionManager;
import org.springframework.transaction.jta.JtaTransactionManager;

@ApplicationScoped
public class JmsRoutes extends RouteBuilder {

    @Inject
    ComponentScheme componentScheme;

    @Inject
    TransactionManager transactionManager;

    @Override
    public void configure() throws Exception {

        fromF("%s:queue:testJmsTransferExchange?transferExchange=true", componentScheme)
                .to("mock:transferExchangeResult");

        fromF("%s:queue:testJmsTransferException?transferException=true", componentScheme)
                .throwException(new IllegalStateException("Forced exception"));

        from("direct:computedDestination")
                .bean("destinationHeaderSetter")
                .toF("%s:queue:override", componentScheme);

        fromF("%s:queue:xa?transactionManager=#jtaTransactionManager", componentScheme)
                .routeId("xaConsumer")
                .log("Received message ${body}")
                .to("mock:xaResult");

        from("direct:xa")
                .routeId("xa")
                .transacted()
                .process(x -> {
                    transactionManager.getTransaction().enlistResource(new DummyXAResource());
                })
                .toF("%s:queue:xa?disableReplyTo=true", componentScheme)
                .choice()
                .when(body().startsWith("fail"))
                .log("Forced to rollback")
                .process(x -> {
                    transactionManager.setRollbackOnly();
                })
                .otherwise()
                .log("Message added: ${body}")
                .endChoice();
    }

    @Named("jtaTransactionManager")
    public PlatformTransactionManager getTransactionManager() {
        return new JtaTransactionManager(transactionManager);
    }
}
